# Generated by roxygen2: do not edit by hand

S3method(plot,npf_seir)
S3method(predict,npf_seir)
S3method(print,npf_seir)
S3method(summary,npf_seir)
export(cori_rt)
export(npf_seir)
export(ou_params)
export(seir_simulate)
importFrom(grDevices,adjustcolor)
importFrom(graphics,abline)
importFrom(graphics,legend)
importFrom(graphics,lines)
importFrom(graphics,mtext)
importFrom(graphics,par)
importFrom(graphics,plot)
importFrom(graphics,polygon)
importFrom(stats,median)
importFrom(stats,pgamma)
importFrom(stats,predict)
importFrom(stats,qgamma)
importFrom(stats,quantile)
importFrom(stats,rgamma)
importFrom(stats,rnorm)
importFrom(stats,rpois)
importFrom(stats,runif)
importFrom(stats,weighted.mean)
