% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/methods.R
\name{print.npf_seir}
\alias{print.npf_seir}
\title{Print method for npf_seir}
\usage{
\method{print}{npf_seir}(x, ...)
}
\arguments{
\item{x}{An \code{npf_seir} object.}

\item{...}{Ignored.}
}
\description{
Print method for npf_seir
}
\value{
Returns \code{x} invisibly. Called primarily for its side effect of
printing a concise summary to the console, including the number of
observations and particles, and the posterior means of the
Ornstein-Uhlenbeck hyperparameters \eqn{\kappa}, \eqn{\sigma_\Psi},
and \eqn{\mu_\Psi} at the final time step.
}
